

# https://bugzilla.redhat.com/show_bug.cgi?id=995136#c12
%global _find_debuginfo_dwz_opts %{nil}
%global _dwz_low_mem_die_limit 0

%global import_path github.com/cri-o/cri-o
%global service_name crio
%global golang_version 1.12.10

Name: cri-o
Version: 1.15.3
Release: 1.0.2%{?dist}
ExcludeArch: ppc64
Summary: Kubernetes Container Runtime Interface for OCI-based containers
License: ASL 2.0
URL: https://%{import_path}
Vendor:  Oracle America
Source0: %{name}-%{version}.tar.bz2
Source3: %{service_name}-network.sysconfig
Source4: %{service_name}-storage.sysconfig
# 1.15 and above
Source5: %{service_name}-metrics.sysconfig

BuildRequires: golang >= %{golang_version}
BuildRequires: btrfs-progs-devel
BuildRequires: device-mapper-devel
BuildRequires: git
BuildRequires: glib2-devel
BuildRequires: glibc-static
BuildRequires: go-md2man
BuildRequires: gpgme-devel
BuildRequires: libassuan-devel
BuildRequires: libseccomp-devel
BuildRequires: pkgconfig(systemd)
BuildRequires: make
Requires(pre): container-selinux
Requires: %{_sysconfdir}/cri-tools/1.15
Requires: containers-common >= 1:0.1.31-14
Requires: runc >= 1.0.0-16
Obsoletes: ocid <= 0.3
Provides: ocid = %{version}-%{release}
Provides: %{service_name} = %{version}-%{release}
Provides: %{_sysconfdir}/crio/1.15
Requires: kubernetes-cni-plugins >= 0.7.5
Requires: conmon = %{version}-%{release}
Requires: socat

%description
%{summary}
%package -n conmon
Summary: OCI container runtime monitor

%description -n conmon
conmon is an OCI container runtime monitor.

%prep
%setup -q

%build
export GOPATH=$(pwd)
export GO111MODULE=off
export GO_MD2MAN=%{_bindir}/go-md2man

make all

%install
# Create a version file so this project can be bounded as a dependency
install -dp %{buildroot}%{_sysconfdir}/crio
touch %{buildroot}%{_sysconfdir}/crio/1.15

# Edit the crio and crio-wipe unit file to have to correct binary location on the system
sed -i 's/\/local//' contrib/systemd/crio.service

# crio wipe was added in 1.15 and above
sed -i 's/\/local//' contrib/systemd/crio-wipe.service

# install conf files
install -dp %{buildroot}%{_sysconfdir}/cni/net.d
install -p -m 644 contrib/cni/10-crio-bridge.conf %{buildroot}%{_sysconfdir}/cni/net.d/100-crio-bridge.conf
install -p -m 644 contrib/cni/99-loopback.conf %{buildroot}%{_sysconfdir}/cni/net.d/200-loopback.conf

install -dp %{buildroot}%{_sysconfdir}/sysconfig
install -p -m 644 contrib/sysconfig/%{service_name} %{buildroot}%{_sysconfdir}/sysconfig/%{service_name}
install -p -m 644 %{SOURCE3} %{buildroot}%{_sysconfdir}/sysconfig/%{service_name}-network
install -p -m 644 %{SOURCE4} %{buildroot}%{_sysconfdir}/sysconfig/%{service_name}-storage
# 1.15 and above
install -p -m 644 %{SOURCE5} %{buildroot}%{_sysconfdir}/sysconfig/%{service_name}-metrics

export GOPATH=$(pwd)
export GO111MODULE=off
export GO_MD2MAN=%{_bindir}/go-md2man

make PREFIX=%{buildroot}%{_usr} DESTDIR=%{buildroot} \
            install.bin \
            install.completions \
            install.config \
            install.man \
            install.systemd

./bin/%{service_name} \
      --selinux \
      --cgroup-manager "cgroupfs" \
      --conmon "%{_libexecdir}/%{service_name}/conmon" \
      --cni-plugin-dir "%{_libexecdir}/cni" \
      --default-mounts "%{_datadir}/rhel/secrets:/run/secrets" \
      config > %{service_name}.conf

install -p -m 644 %{service_name}.conf %{buildroot}%{_sysconfdir}/%{service_name}/%{service_name}.conf

%post
%systemd_post %{service_name}

%preun
%systemd_preun %{service_name}

%postun
%systemd_postun_with_restart %{service_name}

%files
%license LICENSE THIRD_PARTY_LICENSES.txt
%{_sysconfdir}/crio/1.15
%doc README.md
%{_bindir}/%{service_name}
%{_mandir}/man5/%{service_name}.conf.5*
%{_mandir}/man8/%{service_name}*.8*
%dir %{_sysconfdir}/%{service_name}
%config(noreplace) %{_sysconfdir}/%{service_name}/%{service_name}.conf
%config(noreplace) %{_sysconfdir}/sysconfig/%{service_name}
%config(noreplace) %{_sysconfdir}/sysconfig/%{service_name}-storage
%config(noreplace) %{_sysconfdir}/sysconfig/%{service_name}-network
# 1.15 and above
%config(noreplace) %{_sysconfdir}/sysconfig/%{service_name}-metrics
%config(noreplace) %{_sysconfdir}/cni/net.d/100-%{service_name}-bridge.conf
%config(noreplace) %{_sysconfdir}/cni/net.d/200-loopback.conf
%config(noreplace) %{_sysconfdir}/crictl.yaml
# 1.15+ files
%{_unitdir}/crio-wipe.service
%{_libexecdir}/crio/crio-wipe/crio-wipe.bash
%{_libexecdir}/crio/crio-wipe/helpers.bash
%{_libexecdir}/crio/crio-wipe/lib.bash

%dir %{_libexecdir}/%{service_name}
%{_libexecdir}/%{service_name}/pause
%{_unitdir}/%{service_name}.service
%{_unitdir}/cri-o.service
%{_unitdir}/%{service_name}-shutdown.service
%dir %{_datadir}/oci-umount
%dir %{_datadir}/oci-umount/oci-umount.d
%{_datadir}/oci-umount/oci-umount.d/%{service_name}-umount.conf
%files -n conmon
%license LICENSE THIRD_PARTY_LICENSES.txt
%doc README.md
%{_libexecdir}/%{service_name}/conmon

%changelog
* Tue Mar 10 2020 Olcne-Builder Jenkins <olcne-builder_us@oracle.com> - 1.15.3-1.0.1
- Added Oracle Specifile Files for cri-o
